==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>详细信息</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有图片</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打开图片</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>没有权限查看图片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍摄日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光时间</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>测光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>闪光灯补偿</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>镜头型号</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>颜色空间</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相机型号</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>图片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>标记</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1视图</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>适应窗口</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>识别文字</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>显示导航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隐藏导航窗口</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>day</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>请输入图片名称</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists, please use another name</source>
        <translation>文件名“%1”已被占用，请使用其他名称</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未发现图片文件</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未发现图片文件</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>没有权限查看文件</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.25.orig.tar.xz: image-editor-1.0.25/libimageviewer/translations/libimageviewer_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>详细信息</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有图片</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打开图片</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>没有权限查看图片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍摄日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光时间</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>测光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>闪光灯补偿</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>镜头型号</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>颜色空间</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相机型号</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>图片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>标记</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1视图</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>适应窗口</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>识别文字</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>显示导航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隐藏导航窗口</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
    <message>
        <source>day</source>
        <translation>天</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片信息</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>请输入图片名称</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation>文件名已被占用，请使用其他名称</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未发现图片文件</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未发现图片文件</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>没有权限查看文件</translation>
    </message>
</context>
</TS>
